api.currentuser.v1.permission.test_helpers.permission package — Argus-Toolbelt 1.0 documentation

# api.currentuser.v1.permission.test_helpers.permission package

## Submodules

## api.currentuser.v1.permission.test_helpers.permission.check_permission module

`api.currentuser.v1.permission.test_helpers.permission.check_permission.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/currentuser/v1/permission/w+/w+, respond with HTTP 403

`api.currentuser.v1.permission.test_helpers.permission.check_permission.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/currentuser/v1/permission/w+/w+, respond with HTTP 404

`api.currentuser.v1.permission.test_helpers.permission.check_permission.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/currentuser/v1/permission/w+/w+, respond with HTTP 200

`api.currentuser.v1.permission.test_helpers.permission.check_permission.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/currentuser/v1/permission/w+/w+, respond with HTTP 401

## Module contents